bodhi.server.models
===================

.. automodule:: bodhi.server.models

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      BodhiBase
      Bug
      BugKarma
      Build
      BuildrootOverride
      CVE
      Comment
      Compose
      ComposeState
      ContainerBuild
      ContainerPackage
      ContentType
      DeclEnum
      DeclEnumType
      EnumMeta
      EnumSymbol
      Group
      ModuleBuild
      ModulePackage
      Package
      Release
      ReleaseState
      RpmBuild
      RpmPackage
      Stack
      TestCase
      TestCaseKarma
      TestGatingStatus
      Update
      UpdateRequest
      UpdateSeverity
      UpdateStatus
      UpdateSuggestion
      UpdateType
      User
   
   

   
   
   